@@ -8,7 +8,7 @@ class RecordSerializer(serializers.ModelSerializer):
     class Meta:
         fields = [
             "id",
-            "dif_value",
+            "diff_value",
             "next_value",
             "created",
             "user",
@@ -27,7 +27,16 @@ class RecordsFilter(filters.FilterSet):
         model = Record
 
 
-class RecordsViewSet(MunityViewSet):
+class RecordsViewSet(viewsets.ModelViewSet):
+
+    def get_queryset(self):
+        model = self.serializer_class.Meta.model
+
+        # filter request to current model workspace
+        if "workspace_pk" in self.kwargs:
+            return model.objects.filter(workspace=self.kwargs["workspace_pk"])
+        return model.objects.all()
+
     serializer_class = RecordSerializer
     filterset_class = RecordsFilter
 
